//go:build 5BytesOffset
// +build 5BytesOffset

package util

const (
	SizeLimit         = "8000GB"
	VolumeSizeLimitGB = 8000
)
